@@ -1,7 +1,7 @@
 package List::Lazy;
 our $AUTHORITY = 'cpan:YANICK'; 
 # ABSTRACT: Generate lists lazily
-$List::Lazy::VERSION = '0.1.0';
+$List::Lazy::VERSION = '0.2.0';
 
 
 
@@ -10,7 +10,7 @@ use MooX::HandlesVia;
 
 use Clone qw/ clone /;
 
-use 5.20.0;
+use 5.22.0;
 
 use experimental 'signatures', 'postderef';
 
@@ -33,14 +33,14 @@ sub _exporter_validate_opts {
 
 our @EXPORT_OK = qw/ lazy_list lazy_range lazy_fixed_list /;
 
-sub lazy_list :prototype(&@) ($generator,$state=undef) {
+sub lazy_list ($generator,$state=undef) :prototype(&@) {
     return List::Lazy->new(
         generator => $generator,
         state     => $state,
     );
 }
 
-sub lazy_range :prototype($$@) ($min,$max,$step=1) {
+sub lazy_range ($min,$max,$step=1) :prototype($$@) {
     my $it = ref $step ? $step : sub { $_ + $step };
 
     return scalar lazy_list { 
@@ -142,6 +142,24 @@ sub map($self,$map) {
     );
 }
 
+sub batch($self,$n) {
+    return List::Lazy->new(
+        state => [ $self->_clone, [] ],
+        generator => sub {
+            my $stash  = $_->[1];
+
+            while( my @next = $_->[0]->next ) {
+                push @$stash, @next;
+                if( @$stash >= $n ) {
+                    return [ splice @$stash, 0, $n ];
+                }
+            }
+
+            return @$stash ? [ splice @$stash ] : ();
+        },
+    );
+};
+
 sub grep($self,$filter) {
     $self->map(sub{ $filter->() ? $_ : () })
 }
@@ -211,7 +229,7 @@ List::Lazy - Generate lists lazily
 
 =head1 VERSION
 
-version 0.1.0
+version 0.2.0
 
 =head1 SYNOPSIS
 
@@ -312,6 +330,17 @@ If C<$initial_value> is not given, it defaults to the first element of the list.
 
     my $sum = lazy_range( 1, 100 )->reduce( sub { $a + $b } );
 
+=head2 batch
+
+    my $new_list = $list->batch($n);
+
+Creates a new list where the items of the original list are batched in groups
+of C<$n> (or less for the last batch).
+
+    my $list = lazy_fixed_list( 1..100 )->batch(3);
+    
+    my $x = $list->next;           # $x == [ 1, 2, 3]
+
 =head2 map
 
     my $new_list = $list->map( $mapper_sub );
